@@ -26,9 +26,9 @@ func OptionIncludeRules(ruleIDs []string) func(s *Scanner) {
 	}
 }
 
-func OptionIgnoreCheckErrors(ignore bool) func(s *Scanner) {
+func OptionStopOnErrors() func(s *Scanner) {
 	return func(s *Scanner) {
-		s.ignoreCheckErrors = ignore
+		s.ignoreCheckErrors = false
 	}
 }
 
